class GlobalConsts:
    def __init__(self) -> None:
        self.MAX_BYTES = 65535
        self.server_port = 9908
        self.apiPath = "http://127.0.0.1:9908/net_api"
        self.selfUsername = "";